@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-28 18:03:59
-@LastEditTime: 2021-09-02 10:18:14
+@LastEditTime: 2021-09-02 10:40:30
 @LastEditors: HuangJianYi
 :description: 主题皮肤
 """
@@ -34,7 +34,7 @@ class ThemeListHandler(SevenBaseHandler):
         power_menu_list = self.get_power_menu(app_id)
         if len(power_menu_list)>0:
             for i in power_menu_list:
-                if i in [322922329844087484,500255366806462773]:
+                if i in ['322922329844087484', '500255366806462773']:
                     where += " and app_id=%s"
                     params.append(app_id)
                     break
